@@ -297,8 +297,9 @@ class SimpleROC(object):
                 aucs.append(auc(self.fpr_fold[i], self.tpr_fold[i]))
             # endfor
 
-            mean_tpr          = np.mean(tprs, axis=0)
-            self.AUCofMeanROC = auc(mean_fpr, mean_tpr)
+            self.mean_tpr     = np.mean(tprs, axis=0)
+            self.mean_fpr     = mean_fpr
+            self.AUCofMeanROC = auc(self.mean_fpr, self.mean_tpr)
             self.meanAUC      = np.mean(aucs)
             self.stdAUC       = np.std(aucs)
             self.AUCs         = aucs
@@ -308,6 +309,12 @@ class SimpleROC(object):
         #endif
     #enddef
 
+    def computeMeanROC(self):
+        # we compute the mean ROC curve in the process of getting the meanAUC...
+        self.getMeanAUC_andCI()
+        return
+    #enddef
+
     def getMeanAUC_andCI(self):
         import numpy as np
         from sklearn.metrics import auc
@@ -334,8 +341,9 @@ class SimpleROC(object):
                 aucs.append(auc(self.fpr_fold[i], self.tpr_fold[i]))
             # endfor
 
-            mean_tpr          = np.mean(tprs, axis=0)
-            self.AUCofMeanROC = auc(mean_fpr, mean_tpr)
+            self.mean_fpr     = mean_fpr
+            self.mean_tpr     = np.mean(tprs, axis=0)
+            self.AUCofMeanROC = auc(self.mean_fpr, self.mean_tpr)
             self.meanAUC      = np.mean(aucs)
             self.stdAUC       = np.std(aucs)
             self.AUCs         = aucs
